==> qmmp-plugin-pack-0.10.0.tar.bz2: qmmp-plugin-pack-0.10.0/src/Input/ffap/translations/ffap_plugin_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru">
<context>
    <name>DecoderFFapFactory</name>
    <message>
        <location filename="../decoderffapfactory.cpp" line="53"/>
        <source>FFap Plugin</source>
        <translation>Модуль FFap</translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="55"/>
        <source>Monkey&apos;s Audio Files</source>
        <translation>Файлы Monkey&apos;s Audio</translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="163"/>
        <source>About FFap Audio Plugin</source>
        <translation>Об аудио-модуле FFap для Qmmp</translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="164"/>
        <source>Qmmp FFap Audio Plugin</source>
        <translation>Аудио-модуль FFap для Qmmp</translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="165"/>
        <source>This plugin provides Monkey&apos;s Audio (APE) support</source>
        <translation>Данный модуль добавляет поддержку Monkey&apos;s Audio (APE)</translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="166"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Разработчик: Илья Котов &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="167"/>
        <source>Based on code from deadbeef, FFmpeg and rockbox</source>
        <translation>Основан на исходном коде проектов deadbeef, FFmpeg и rockbox</translation>
    </message>
</context>
<context>
    <name>FFapMetaDataModel</name>
    <message>
        <location filename="../ffapmetadatamodel.cpp" line="60"/>
        <source>Length</source>
        <translation>Длительность</translation>
    </message>
    <message>
        <location filename="../ffapmetadatamodel.cpp" line="61"/>
        <source>Sample rate</source>
        <translation>Дискретизация</translation>
    </message>
    <message>
        <location filename="../ffapmetadatamodel.cpp" line="61"/>
        <source>Hz</source>
        <translation>Гц</translation>
    </message>
    <message>
        <location filename="../ffapmetadatamodel.cpp" line="62"/>
        <source>Channels</source>
        <translation>Каналов</translation>
    </message>
    <message>
        <location filename="../ffapmetadatamodel.cpp" line="63"/>
        <source>Bitrate</source>
        <translation>Битовая частота</translation>
    </message>
    <message>
        <location filename="../ffapmetadatamodel.cpp" line="63"/>
        <source>kbps</source>
        <translation>Кб/с</translation>
    </message>
    <message>
        <location filename="../ffapmetadatamodel.cpp" line="64"/>
        <source>File size</source>
        <translation>Размер файла</translation>
    </message>
    <message>
        <location filename="../ffapmetadatamodel.cpp" line="64"/>
        <source>KB</source>
        <translation>КБ</translation>
    </message>
</context>
</TS>

==> qmmp-plugin-pack-0.10.3.tar.bz2: qmmp-plugin-pack-0.10.3/src/Input/ffap/translations/ffap_plugin_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru">
<context>
    <name>DecoderFFapFactory</name>
    <message>
        <location filename="../decoderffapfactory.cpp" line="53"/>
        <source>FFap Plugin</source>
        <translation>Модуль FFap</translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="55"/>
        <source>Monkey&apos;s Audio Files</source>
        <translation>Файлы Monkey&apos;s Audio</translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="163"/>
        <source>About FFap Audio Plugin</source>
        <translation>Об аудио-модуле FFap для Qmmp</translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="164"/>
        <source>Qmmp FFap Audio Plugin</source>
        <translation>Аудио-модуль FFap для Qmmp</translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="165"/>
        <source>This plugin provides Monkey&apos;s Audio (APE) support</source>
        <translation>Данный модуль добавляет поддержку Monkey&apos;s Audio (APE)</translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="166"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Разработчик: Илья Котов &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="167"/>
        <source>Based on code from deadbeef, FFmpeg and rockbox</source>
        <translation>Основан на исходном коде проектов deadbeef, FFmpeg и rockbox</translation>
    </message>
</context>
<context>
    <name>FFapMetaDataModel</name>
    <message>
        <location filename="../ffapmetadatamodel.cpp" line="60"/>
        <source>Length</source>
        <translation>Длительность</translation>
    </message>
    <message>
        <location filename="../ffapmetadatamodel.cpp" line="61"/>
        <source>Sample rate</source>
        <translation>Дискретизация</translation>
    </message>
    <message>
        <location filename="../ffapmetadatamodel.cpp" line="61"/>
        <source>Hz</source>
        <translation>Гц</translation>
    </message>
    <message>
        <location filename="../ffapmetadatamodel.cpp" line="62"/>
        <source>Channels</source>
        <translation>Каналов</translation>
    </message>
    <message>
        <location filename="../ffapmetadatamodel.cpp" line="63"/>
        <source>Bitrate</source>
        <translation>Битовая частота</translation>
    </message>
    <message>
        <location filename="../ffapmetadatamodel.cpp" line="63"/>
        <source>kbps</source>
        <translation>кбит/с</translation>
    </message>
    <message>
        <location filename="../ffapmetadatamodel.cpp" line="64"/>
        <source>File size</source>
        <translation>Размер файла</translation>
    </message>
    <message>
        <location filename="../ffapmetadatamodel.cpp" line="64"/>
        <source>KB</source>
        <translation>КБ</translation>
    </message>
</context>
</TS>
